import { css, html, LitElement } from "lit";
import { customElement, property } from "lit/decorators.js";

enum ButtonType {
  Primary = "primary",
  Reverse = "reverse",
}

@customElement("opco-button")
export class ComponentWrapper extends LitElement {
  static override styles = css`
    .button {
      all: unset;
      padding: 12px;
      border-radius: 8px;
      cursor: pointer;
      font-family: "Barlow", sans-serif;
      font-weight: 600;
      font-style: normal;
      border: 1px solid transparent;
    }

    .primary {
      background: #004271;
      color: white;
      border-color: #004271;
    }

    .reverse {
      color: #004271;
      background: white;
      border-color: #004271;
    }
  `;

  toggle() {
    console.log("btn clicked !");
  }

  get classNames() {
    return this.baseClassName + ` ${this.variant}`;
  }

  @property({ attribute: false }) baseClassName = "button";
  @property({ type: String }) label = "";
  @property({ type: String }) variant: ButtonType = ButtonType.Primary;

  override render() {
    return html`
      <button class="${this.classNames}" @click="${this.toggle}">
        ${this.label}
      </button>
    `;
  }
}
